import { __awaiter, __generator } from "tslib";
import { FetchError } from "configcat-common";
var HttpConfigFetcher = /** @class */ (function () {
    function HttpConfigFetcher() {
    }
    HttpConfigFetcher.prototype.fetchLogic = function (options, lastEtag) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function () {
            var requestInit, cleanup, controller_1, timeoutId_1, url, response, statusCode, reasonPhrase, body, eTag, err_1;
            return __generator(this, function (_d) {
                switch (_d.label) {
                    case 0:
                        requestInit = { method: "GET" };
                        // NOTE: Older Chromium versions (e.g. the one used in our tests) may not support AbortController.
                        if (typeof AbortController !== "undefined") {
                            controller_1 = new AbortController();
                            timeoutId_1 = setTimeout(function () { return controller_1.abort(); }, options.requestTimeoutMs);
                            requestInit.signal = controller_1.signal;
                            cleanup = function () { return clearTimeout(timeoutId_1); };
                        }
                        else {
                            cleanup = function () { };
                        }
                        _d.label = 1;
                    case 1:
                        _d.trys.push([1, 6, 7, 8]);
                        url = options.getUrl();
                        if (lastEtag) {
                            // We are sending the etag as a query parameter so if the browser doesn't automatically adds the If-None-Match header, we can transform this query param to the header in our CDN provider.
                            url += "&ccetag=" + encodeURIComponent(lastEtag);
                        }
                        return [4 /*yield*/, fetch(url, requestInit)];
                    case 2:
                        response = _d.sent();
                        statusCode = response.status, reasonPhrase = response.statusText;
                        if (!(statusCode === 200)) return [3 /*break*/, 4];
                        return [4 /*yield*/, response.text()];
                    case 3:
                        body = _d.sent();
                        eTag = (_b = (_a = response.headers) === null || _a === void 0 ? void 0 : _a.get("Etag")) !== null && _b !== void 0 ? _b : void 0;
                        return [2 /*return*/, { statusCode: statusCode, reasonPhrase: reasonPhrase, eTag: eTag, body: body }];
                    case 4: return [2 /*return*/, { statusCode: statusCode, reasonPhrase: reasonPhrase }];
                    case 5: return [3 /*break*/, 8];
                    case 6:
                        err_1 = _d.sent();
                        if (err_1 instanceof DOMException && err_1.name === "AbortError") {
                            if ((_c = requestInit.signal) === null || _c === void 0 ? void 0 : _c.aborted) {
                                throw new FetchError("timeout", options.requestTimeoutMs);
                            }
                            else {
                                throw new FetchError("abort");
                            }
                        }
                        throw new FetchError("failure", err_1);
                    case 7:
                        cleanup();
                        return [7 /*endfinally*/];
                    case 8: return [2 /*return*/];
                }
            });
        });
    };
    return HttpConfigFetcher;
}());
export { HttpConfigFetcher };
